Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1385)

Unified Diff: third_party/WebKit/Source/core/html/track/CueTimeline.cpp

Issue 2068053002: Rename Blink constants generated from IDL files. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/track/CueTimeline.cpp
diff --git a/third_party/WebKit/Source/core/html/track/CueTimeline.cpp b/third_party/WebKit/Source/core/html/track/CueTimeline.cpp
index 5fff2f514e232f3b4dfc4099112e64fe3f14a025..d3c8ea0d98005205b92bbed4cac1c539951f7838 100644
--- a/third_party/WebKit/Source/core/html/track/CueTimeline.cpp
+++ b/third_party/WebKit/Source/core/html/track/CueTimeline.cpp
@@ -147,8 +147,8 @@ void CueTimeline::updateActiveCues(double movieTime)
CueList currentCues;
// The user agent must synchronously unset [the text track cue active] flag
- // whenever ... the media element's readyState is changed back to HAVE_NOTHING.
- if (mediaElement.getReadyState() != HTMLMediaElement::HAVE_NOTHING && mediaElement.webMediaPlayer())
+ // whenever ... the media element's readyState is changed back to kHaveNothing.
+ if (mediaElement.getReadyState() != HTMLMediaElement::kHaveNothing && mediaElement.webMediaPlayer())
currentCues = m_cueTree.allOverlaps(m_cueTree.createInterval(movieTime, movieTime));
CueList previousCues;
« no previous file with comments | « third_party/WebKit/Source/core/html/MediaError.h ('k') | third_party/WebKit/Source/core/html/track/LoadableTextTrack.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698